@@ -37,7 +37,7 @@ from stestr import user_config
 def _to_int(possible, default=0, out=sys.stderr):
     try:
         i = int(possible)
-    except ValueError:
+    except (ValueError, TypeError):
         i = default
         msg = ('Unable to convert "%s" to an integer.  Using %d.\n' %
                (possible, default))
@@ -152,12 +152,22 @@ class Run(command.Command):
                             help='If set do not print stdout or stderr '
                             'attachment contents on a successful test '
                             'execution')
+        parser.add_argument('--all-attachments', action='store_true',
+                            dest='all_attachments',
+                            help='If set print all text attachment contents on'
+                            ' a successful test execution')
         return parser
 
     def take_action(self, parsed_args):
         user_conf = user_config.get_user_config(self.app_args.user_config)
         filters = parsed_args.filters
         args = parsed_args
+        if args.suppress_attachments and args.all_attachments:
+            msg = ("The --suppress-attachments and --all-attachments "
+                   "options are mutually exclusive, you can not use both "
+                   "at the same time")
+            print(msg)
+            sys.exit(1)
         if getattr(user_conf, 'run', False):
             if not user_conf.run.get('no-subunit-trace'):
                 if not args.no_subunit_trace:
@@ -176,9 +186,19 @@ class Run(command.Command):
             color = args.color or user_conf.run.get('color', False)
             abbreviate = args.abbreviate or user_conf.run.get(
                 'abbreviate', False)
-            suppress_attachments = (
-                args.suppress_attachments or user_conf.run.get(
-                    'suppress-attachments', False))
+            suppress_attachments_conf = user_conf.run.get(
+                'suppress-attachments', False)
+            all_attachments_conf = user_conf.run.get(
+                'all-attachments', False)
+            if not args.suppress_attachments and not args.all_attachments:
+                suppress_attachments = suppress_attachments_conf
+                all_attachments = all_attachments_conf
+            elif args.suppress_attachments:
+                all_attachments = False
+                suppress_attachments = args.suppress_attachments
+            elif args.all_attachments:
+                suppress_attachments = False
+                all_attachments = args.all_attachments
         else:
             pretty_out = args.force_subunit_trace or not args.no_subunit_trace
             concurrency = args.concurrency or 0
@@ -186,6 +206,7 @@ class Run(command.Command):
             color = args.color
             abbreviate = args.abbreviate
             suppress_attachments = args.suppress_attachments
+            all_attachments = args.all_attachments
         verbose_level = self.app.options.verbose_level
         stdout = open(os.devnull, 'w') if verbose_level == 0 else sys.stdout
         # Make sure all (python) callers have provided an int()
@@ -210,7 +231,8 @@ class Run(command.Command):
             combine=args.combine,
             filters=filters, pretty_out=pretty_out, color=color,
             stdout=stdout, abbreviate=abbreviate,
-            suppress_attachments=suppress_attachments)
+            suppress_attachments=suppress_attachments,
+            all_attachments=all_attachments)
 
         # Always output slowest test info if requested, regardless of other
         # test run options
@@ -250,7 +272,8 @@ def run_command(config='.stestr.conf', repo_type='file',
                 blacklist_file=None, whitelist_file=None, black_regex=None,
                 no_discover=False, random=False, combine=False, filters=None,
                 pretty_out=True, color=False, stdout=sys.stdout,
-                abbreviate=False, suppress_attachments=False):
+                abbreviate=False, suppress_attachments=False,
+                all_attachments=False):
     """Function to execute the run command
 
     This function implements the run command. It will run the tests specified
@@ -311,6 +334,8 @@ def run_command(config='.stestr.conf', repo_type='file',
     :param bool abbreviate: Use abbreviated output if set true
     :param bool suppress_attachments: When set true attachments subunit_trace
         will not print attachments on successful test execution.
+    :param bool all_attachments: When set true subunit_trace will print all
+        text attachments on successful test execution.
 
     :return return_code: The exit code for the command. 0 for success and > 0
         for failures.
@@ -348,7 +373,15 @@ def run_command(config='.stestr.conf', repo_type='file',
         if ids.find('/') != -1:
             root = ids.replace('.py', '')
             ids = root.replace('/', '.')
-        run_cmd = 'python -m subunit.run ' + ids
+        stestr_python = sys.executable
+        if os.environ.get('PYTHON'):
+            python_bin = os.environ.get('PYTHON')
+        elif stestr_python:
+            python_bin = stestr_python
+        else:
+            raise RuntimeError("The Python interpreter was not found and "
+                               "PYTHON is not set")
+        run_cmd = python_bin + ' -m subunit.run ' + ids
 
         def run_tests():
             run_proc = [('subunit', output.ReturnCodeToSubunit(
@@ -360,7 +393,8 @@ def run_command(config='.stestr.conf', repo_type='file',
                              repo_url=repo_url, run_id=combine_id,
                              pretty_out=pretty_out,
                              color=color, stdout=stdout, abbreviate=abbreviate,
-                             suppress_attachments=suppress_attachments)
+                             suppress_attachments=suppress_attachments,
+                             all_attachments=all_attachments)
 
         if not until_failure:
             return run_tests()
@@ -431,7 +465,8 @@ def run_command(config='.stestr.conf', repo_type='file',
                     subunit_out=subunit_out, combine_id=combine_id,
                     repo_type=repo_type, repo_url=repo_url,
                     pretty_out=pretty_out, color=color, abbreviate=abbreviate,
-                    stdout=stdout, suppress_attachments=suppress_attachments)
+                    stdout=stdout, suppress_attachments=suppress_attachments,
+                    all_attachments=all_attachments)
                 if run_result > result:
                     result = run_result
             return result
@@ -445,7 +480,8 @@ def run_command(config='.stestr.conf', repo_type='file',
                               color=color,
                               stdout=stdout,
                               abbreviate=abbreviate,
-                              suppress_attachments=suppress_attachments)
+                              suppress_attachments=suppress_attachments,
+                              all_attachments=all_attachments)
     else:
         # Where do we source data about the cause of conflicts.
         latest_run = repo.get_latest_run()
@@ -489,7 +525,8 @@ def run_command(config='.stestr.conf', repo_type='file',
 def _run_tests(cmd, until_failure,
                subunit_out=False, combine_id=None, repo_type='file',
                repo_url=None, pretty_out=True, color=False, stdout=sys.stdout,
-               abbreviate=False, suppress_attachments=False):
+               abbreviate=False, suppress_attachments=False,
+               all_attachments=False):
     """Run the tests cmd was parameterised with."""
     cmd.setUp()
     try:
@@ -506,7 +543,8 @@ def _run_tests(cmd, until_failure,
                              repo_url=repo_url, run_id=combine_id,
                              pretty_out=pretty_out, color=color, stdout=stdout,
                              abbreviate=abbreviate,
-                             suppress_attachments=suppress_attachments)
+                             suppress_attachments=suppress_attachments,
+                             all_attachments=all_attachments)
 
         if not until_failure:
             return run_tests()
